Welcome to the Plaso documentation!
=======================================
Plaso (Plaso Langar Að Safna Öllu) is a computer forensic tool for timeline generation and analysis.


Plaso's documentation is split into several parts:


-  `User documentation <sources/user/Users-Guide.html>`__
-  `Developer documentation <sources/developer/Developers-Guide.html>`__
-  `API documentation <sources/api/plaso.html>`__


The project's code is available from https://github.com/log2timeline/plaso

Plaso is licensed under the Apache license version 2.

Contents:

.. toctree::
   :maxdepth: 3

   sources/user/index

.. toctree::
   :maxdepth: 3

   sources/developer/index

.. toctree::
   :maxdepth: 3

   API documentation <sources/api/plaso>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

